@@ -49,6 +49,15 @@
 #include "tea_enc.h" // Needed for create_enc_list
 
 
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+#include <gtksourceview/gtksourceview.h>
+#include <gtksourceview/gtksourcelanguage.h>
+#include <gtksourceview/gtksourcelanguagemanager.h>
+#include <gtksourceview/gtksourcestyleschememanager.h>
+
+#endif
+
 static GHashTable *tea_options = NULL;
 
 GList* create_supported_markup_modes (void)
@@ -80,9 +89,19 @@ GList* create_tea_special_places (void)
 
 void ui_init (void)
 {
+  b_topmost = FALSE;
   gl_tea_special_places = create_tea_special_places ();
   gl_markup_modes = create_supported_markup_modes ();
   gl_image_formats = image_formats_fill ();
+  gl_color_schemes = NULL;
+
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+  gl_color_schemes = get_color_scheme_ids ();
+
+#endif
+
+  lm_dclick_mode = DCM_NONE;
 
   cur_tea_project = NULL;
   GList *ui = NULL;
@@ -93,19 +112,24 @@ void ui_init (void)
   ui = load_file_to_glist (confile.tea_ui);
   gl_tea_kwas_bookmarks = load_file_to_glist (confile.tea_kwas_bookmarks);
 
+
   confile.def_spell_lang = conf_get_char_value (ui, "def_spell_lang", "en");
   confile.last_version = conf_get_char_value (ui, "last_version", "xxxxxx");
   confile.last_prefs_tab = conf_get_int_value (ui, "last_prefs_tab", 0);
+  confile.filter_index = conf_get_int_value (ui, "filter_index", 0);
 
-  gtk_paned_set_position (vpaned1, conf_get_int_value (ui, "vpaned1_y", 300));
+  gint main_wnd_w = conf_get_int_value (ui, "main_wnd_w", 630);
+  gint main_wnd_h = conf_get_int_value (ui, "main_wnd_h", 450);
+
+  gtk_paned_set_position (vpaned1, conf_get_int_value (ui, "vpaned1_y", get_value (main_wnd_h, 70)));
 
   gtk_window_move (GTK_WINDOW (tea_main_window),
                    conf_get_int_value (ui, "main_wnd_x", 2),
                    conf_get_int_value (ui, "main_wnd_y", 2));
 
-  gtk_window_resize (GTK_WINDOW (tea_main_window),
-                     conf_get_int_value (ui, "main_wnd_w", 630),
-                     conf_get_int_value (ui, "main_wnd_h", 450));
+  gtk_window_resize (GTK_WINDOW (tea_main_window), main_wnd_w, main_wnd_h);
+
+  gtk_widget_set_size_request (pb_status, get_value (main_wnd_w, 60), -1);
 
   confile.default_markup_mode = conf_get_char_value (ui, "default_markup_mode", "HTML");
   def_mm = get_markup_mode ();
@@ -126,6 +150,16 @@ void ui_init (void)
 
 #endif
 
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+  source_languages_manager = gtk_source_language_manager_get_default ();
+  gl_supported_hlangs = NULL;
+
+#endif
+
+  GtkEntryCompletion *cmpl = gtk_entry_get_completion (ent_search);
+  model_fill_from_file (gtk_entry_completion_get_model (cmpl), confile.fam_autocomp_file);
+
   ui_update ();
 }
 
@@ -153,6 +187,7 @@ void ui_done (void)
   if (tea_main_window)
      gtk_window_get_position (GTK_WINDOW (tea_main_window), &x, &y);
 
+  list = add_to_glist_combined_int (list, "filter_index", confile.filter_index);
   list = add_to_glist_combined_int (list, "last_prefs_tab", confile.last_prefs_tab);
   list = add_to_glist_combined_int (list, "main_wnd_x", x);
   list = add_to_glist_combined_int (list, "main_wnd_y", y);
@@ -171,6 +206,9 @@ void ui_done (void)
   glist_save_to_file (list, confile.tea_ui);
   glist_strings_free (gl_autosave);
 
+  GtkEntryCompletion *cmpl = gtk_entry_get_completion (ent_search);
+  model_save_to_file (gtk_entry_completion_get_model (cmpl), confile.fam_autocomp_file);
+
   glist_strings_free (gl_tea_special_places);
 
   g_free (confile.def_spell_lang);
@@ -181,6 +219,7 @@ void ui_done (void)
   glist_strings_free (gl_enc_choosed);
   glist_strings_free (gl_tea_kwas_bookmarks);
   glist_strings_free (gl_markup_modes);
+  glist_strings_free (gl_color_schemes);
 
   if (temp_text_part)
      {
@@ -262,6 +301,7 @@ gint conf_get_int_value (GList *confdata, const gchar *key, gint def)
 //current music: Guano Apes - You Can't Stop Me
 void confile_free (void)
 {
+  g_free (confile.fallback_charset);
   g_free (confile.current_movie);
   g_free (confile.ext_pic_viewer);
   g_free (confile.ext_pic_editor);
@@ -284,6 +324,8 @@ void confile_free (void)
   g_free (confile.tables_dir);
   g_free (confile.bmx_file);
   g_free (confile.date_time);
+  g_free (confile.date_time_ver);
+
   g_free (confile.tea_main_dir);
   g_free (confile.templates_dir);
   g_free (confile.tmp_dir);
@@ -297,8 +339,9 @@ void confile_free (void)
   g_free (confile.scripts_dir);
   g_free (confile.tea_recent);
   g_free (confile.tea_hotkeys);
-  g_free (confile.tea_hotkeys_old);
+//  g_free (confile.tea_hotkeys_old);
 
+  g_free (confile.fam_autocomp_file);
   g_free (confile.def_save_dir);
   g_free (confile.def_open_dir);
   g_free (confile.cmd_def_doc_browser);
@@ -306,7 +349,7 @@ void confile_free (void)
   g_free (confile.fmt_color_function);
   g_free (confile.last_session);
   g_free (confile.autosave_session);
-  //g_free (confile.);
+  g_free (confile.cm_pack);
 
   g_free (confile.text_foreground);
   g_free (confile.text_background);
@@ -368,8 +411,6 @@ void get_iconv_sup (void)
 
   confile.iconv_encs = g_list_prepend (confile.iconv_encs, CHARSET_JAPANESE);
   confile.iconv_encs = g_list_prepend (confile.iconv_encs, "autodetect");
-
-  cur_settings.selected_enc = ch_str (cur_settings.selected_enc, "UTF-8");
 }
 
 
@@ -406,9 +447,7 @@ void execute_recent_item (const gchar *item)
       return;
      }
 
-  cur_settings.selected_enc = ch_str (cur_settings.selected_enc, a[1]);
-
-  cur_text_doc = doc_open_file (f);
+  cur_text_doc = doc_open_file (f, a[1]);
 
   if (cur_text_doc)
      {
@@ -465,7 +504,7 @@ void tea_start (void)
   ui_done_flag = FALSE;
   b_exit_flag = FALSE;
   last_dir = NULL;
-  enc_guess_value = NULL;
+//  enc_guess_value = NULL;
   sr_wnd = NULL;
   ht_ext_programs = NULL;
   ht_autoreplace = NULL;
@@ -488,7 +527,6 @@ void tea_start (void)
   gl_found_files = NULL;
   tooltips = gtk_tooltips_new ();
   gtk_tooltips_enable (tooltips);
-  cur_settings.selected_enc = g_strdup (confile.default_charset);
   gl_enc_available = create_enc_list ();
 
   calendar_init ();
@@ -551,7 +589,7 @@ void tea_done (void)
   g_free (confile.last_version);
   calendar_done ();
   confile_free ();
-
+  spell_checker_done ();
   g_free (last_dir);
 
 #ifdef CHAI_MODE
@@ -564,10 +602,6 @@ void tea_done (void)
 #ifdef SOUNDS_MODE
   sounds_done ();
 #endif
-
-#ifdef ENCHANT_SUPPORTED
-  enchant_done ();
-#endif
 }
 
 
@@ -699,7 +733,7 @@ void reload_dicts (void)
   gtk_widget_destroy (mni_spellcheck_menu);
   mni_spellcheck_menu = new_menu_submenu (mni_spellcheck);
   GtkWidget *temp = new_menu_tof (mni_spellcheck_menu);
-  GList *l = get_speller_modules_list (g_getenv ("LANG"));
+  GList *l = get_speller_modules_list ();
   build_menu_from_glist (l, mni_spellcheck_menu, on_mni_spellcheck);
   glist_strings_free (l);
 
@@ -886,7 +920,6 @@ void confile_reload (void)
   confile.screen_w = gdk_screen_width ();
   confile.screen_h = gdk_screen_height ();
 
-  gchar *old_tea_dir = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".tea", NULL);
   gchar *conf_dir = g_strconcat (g_get_home_dir (), G_DIR_SEPARATOR_S, ".config", NULL);
 
   confile.tea_main_dir = g_strconcat (conf_dir, G_DIR_SEPARATOR_S, "tea", NULL);
@@ -909,8 +942,7 @@ void confile_reload (void)
   confile.last_session = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "last_session", NULL);
   confile.autosave_session = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "autosave_session", NULL);
 
-
-//  confile.fam_autocomp_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "fam_autocomp_file", NULL);
+  confile.fam_autocomp_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "fte_autocomp_file", NULL);
   confile.crash_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "crash_file", NULL);
   confile.autosave_file = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_autosave_list", NULL);
   confile.tea_rc = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_rc", NULL);
@@ -919,7 +951,6 @@ void confile_reload (void)
 
   confile.tea_recent = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_recent", NULL);
   confile.tea_hotkeys = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_keys", NULL);
-  confile.tea_hotkeys_old = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "tea_hotkeys", NULL);
 
   confile.tea_choosed_charsets = g_strconcat (confile.tea_main_dir, G_DIR_SEPARATOR_S, "charsets", NULL);
 
@@ -928,21 +959,12 @@ void confile_reload (void)
         dbm ("I cannot to create $HOME/.config");
 
   if (! g_file_test (confile.tea_main_dir, G_FILE_TEST_EXISTS))
-  if (g_file_test (old_tea_dir, G_FILE_TEST_EXISTS))
-     {
-      gchar *cm = g_strconcat ("mv ", old_tea_dir, " ", confile.tea_main_dir,  NULL);
-      system (cm);
-      g_free (cm);
-     }
-  else
       if (mkdir (confile.tea_main_dir, S_IRUSR | S_IWUSR | S_IXUSR) != 0)
          dbm ("I cannot to create $HOME/.config/tea");
 
-  g_free (old_tea_dir);
-
-/*  if (! g_file_test (confile.fam_autocomp_file, G_FILE_TEST_EXISTS))
+  if (! g_file_test (confile.fam_autocomp_file, G_FILE_TEST_EXISTS))
       create_empty_file (confile.fam_autocomp_file, "alakazar alakazun");
-*/
+
   if (! g_file_test (confile.tea_rc, G_FILE_TEST_EXISTS))
       create_empty_file (confile.tea_rc, _("#TEA editor configuration file. Please read the manual"));
 
@@ -964,11 +986,14 @@ void confile_reload (void)
 
   g_free (x);
 
+  confile.cm_pack = ht_get_char_value ("cm_pack", "zip -j -q -9 %s.zip %s");
   confile.editor_font = ht_get_char_value ("editor_font", "Monospace 12");
 
   confile.ext_pic_editor = ht_get_char_value ("ext_pic_editor", "gimp-remote-2.0 -n %s&");
   confile.ext_pic_viewer = ht_get_char_value ("ext_pic_viewer", "display %s&");
   confile.date_time = ht_get_char_value ("date_time", "%d/%m/%Y %T");
+  confile.date_time_ver = ht_get_char_value ("date_time_ver", "%Y-%m-%d-%T");
+
   confile.max_recent_items = ht_get_int_value ("max_recent_items", 12);
 
   confile.max_undo_levels =  ht_get_int_value ("max_undo_levels", 32);
@@ -984,6 +1009,7 @@ void confile_reload (void)
   confile.now_playing = ht_get_char_value ("now_playing", "Now playing %s");
 
   confile.show_cursor_pos = ht_get_int_value ("show_cursor_pos", 0);
+  confile.enc_use_fallback = ht_get_int_value ("enc_use_fallback", 1);
 
   confile.saveopen_h = ht_get_int_value ("saveopen_h", 75);
   confile.saveopen_w = ht_get_int_value ("saveopen_w", 75);
@@ -1011,7 +1037,9 @@ void confile_reload (void)
   confile.tab_size = ht_get_int_value ("tab_size", 3);
 
   confile.fmt_color_function = ht_get_char_value ("fmt_color_function", "<span style=\"color:@color;\">@text</span>");
+  confile.fallback_charset = ht_get_char_value ("fallback_charset", "ISO-8859-1");
 
+  confile.def_color_id = ht_get_char_value ("def_color_id", "kate");
   confile.def_file_ext = ht_get_char_value ("def_file_ext", "txt");
   confile.add_def_file_ext = ht_get_int_value ("add_def_file_ext", 0);
 
@@ -1089,7 +1117,7 @@ void confile_reload (void)
 
   confile.main_wnd_show_full_path = ht_get_int_value ("main_wnd_show_full_path", 1);
   confile.do_backup = ht_get_int_value ("do_backup", 0);
-  confile.do_hl_on_fileopen = ht_get_int_value ("do_hl_on_fileopen", 1);
+//  confile.do_hl_on_fileopen = ht_get_int_value ("do_hl_on_fileopen", 1);
   confile.show_hidden_files = ht_get_int_value ("show_hidden_files", 1);
   confile.implane_ins_image = ht_get_int_value ("implane_ins_image", 0);
 
@@ -1125,9 +1153,9 @@ void confile_reload (void)
   confile.enc_det_turkish = ht_get_int_value ("enc_det_turkish", 0);
 
   confile.scan_for_links_on_doc_open = ht_get_int_value ("scan_for_links_on_doc_open", 0);
-  confile.logmemo_lines_max = ht_get_int_value ("logmemo_lines_max", 13);
+  confile.logmemo_lines_max = ht_get_int_value ("logmemo_lines_max", 777);
 //  confile.fam_autocomp_lines_max = ht_get_int_value ("fam_autocomp_lines_max", 1024);
- // confile.fam_min_prefix_len = ht_get_int_value ("fam_min_prefix_len", 1);
+  confile.fte_min_prefix_len = ht_get_int_value ("fte_min_prefix_len", 3);
 
   g_hash_table_destroy (ht_config);
 
@@ -1290,25 +1318,37 @@ void hotkeys_initial_check (void)
   gchar *old_keys;
   gchar *new_keys;
 
-  if (g_file_test (confile.tea_hotkeys_old, G_FILE_TEST_EXISTS))
+  if (! g_file_test (confile.tea_hotkeys, G_FILE_TEST_EXISTS))
      {
       def_keys = get_default_shortcuts ();
-      old_keys = str_file_read (confile.tea_hotkeys_old);
-      new_keys = g_strconcat (def_keys, "\n", old_keys, NULL);
-
-      save_string_to_file (confile.tea_hotkeys, new_keys);
-      unlink (confile.tea_hotkeys_old);
-
+      save_string_to_file (confile.tea_hotkeys, def_keys);
       g_free (def_keys);
-      g_free (new_keys);
-      g_free (old_keys);
      }
- else
-     if (! g_file_test (confile.tea_hotkeys, G_FILE_TEST_EXISTS))
-        {
-         def_keys = get_default_shortcuts ();
-         save_string_to_file (confile.tea_hotkeys, def_keys);
-         g_free (def_keys);
-        }
 }
 
+
+GList* get_color_scheme_ids (void)
+{
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+#if ((GTK_MAJOR_VERSION >= 2) && (GTK_MINOR_VERSION >= 6))
+  GtkSourceStyleSchemeManager *manager = gtk_source_style_scheme_manager_get_default ();
+
+  gchar **scheme_ids;
+  g_object_get (manager, "scheme-ids", &scheme_ids, NULL);
+
+  GList *ids = NULL;
+  gint c = get_gchar_array_size (scheme_ids) - 1;
+  gint i;
+
+  for (i = 0; i <= c; i++)
+     ids = g_list_prepend (ids, scheme_ids[i]);
+
+
+  return ids;
+#endif
+#else
+
+  return NULL;
+
+#endif
+}
\ No newline at end of file
