@@ -58,7 +58,6 @@
 
 #ifdef CHAI_MODE
 
-
 static GtkSourceTagStyle *cur_tag_style;
 static GtkSourceTag *cur_tag;
 GtkSourceLanguage *cur_language;
@@ -275,6 +274,59 @@ static GtkWidget* wnd_options_hl_chai (void)
 #endif
 
 
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+static void cb_scheme_change (GtkComboBox *combobox,
+                              gpointer user_data)
+{
+  if (! gl_color_schemes)
+     return;
+
+  gint index = gtk_combo_box_get_active (combobox);
+  if (index == -1)
+     return;
+
+  gchar *x = combo_get_value (cbm_color_cheme, gl_color_schemes);
+
+  GtkSourceStyleScheme *shm = gtk_source_style_scheme_manager_get_scheme (gtk_source_style_scheme_manager_get_default (), x);
+
+  gchar *s = g_strconcat (
+                          gtk_source_style_scheme_get_name (shm), "\n",
+                          gtk_source_style_scheme_get_description (shm), "\n",
+                          gtk_source_style_scheme_get_filename (shm),
+                          NULL);
+
+  gtk_text_buffer_set_text (gtk_text_view_get_buffer (user_data), s, -1);
+  g_free (s);
+}
+
+
+static GtkWidget* wnd_options_hl_schemes (void)
+{
+  GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
+  gtk_widget_show (page);
+
+  GtkWidget *vb = gtk_vbox_new (FALSE, UI_PACKFACTOR);
+
+  gtk_widget_show (vb);
+  gtk_box_pack_start (page, vb, FALSE, FALSE, UI_PACKFACTOR);
+
+  GtkWidget *text_view = gtk_text_view_new ();
+
+
+  cbm_color_cheme = tea_combo_combo (vb, gl_color_schemes, _("Highlighting color scheme"),
+                                     find_str_index (gl_color_schemes, confile.def_color_id), cb_scheme_change, text_view);
+
+  gtk_widget_show (text_view);
+
+  gtk_box_pack_start (vb, text_view, FALSE, TRUE, UI_PACKFACTOR);
+
+
+  return page;
+}
+#endif
+
+
 static void cb_put_launcher (GtkButton *button,
                              gpointer user_data)
 {
@@ -289,21 +341,6 @@ static void cb_del_launcher (GtkButton *button,
 }
 
 
-static void cb_on_choose_enc (GtkButton *button,
-                              gpointer user_data)
-{
-  gchar *s = tv_get_selected_single (tv_available_charsets);
-  if (! s)
-     return;
-
-  gl_enc_choosed = g_list_prepend (gl_enc_choosed, g_strdup (s));
-  tv_fill_with_glist (tv_choosed_charsets, gl_enc_choosed);
-
-  glist_save_to_file (gl_enc_choosed, confile.tea_choosed_charsets);
-  get_iconv_sup ();
-}
-
-
 static void cb_on_del_enc (GtkButton *button,
                            gpointer user_data)
 {
@@ -315,6 +352,7 @@ static void cb_on_del_enc (GtkButton *button,
   glist_save_to_file (l, confile.tea_choosed_charsets);
   get_iconv_sup ();
   tv_fill_with_glist (tv_choosed_charsets, gl_enc_choosed);
+  g_free (s);
 }
 
 
@@ -331,6 +369,12 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
 {
    GList *l = NULL;
 
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+
+   l = add_to_glist_combined_str (l, "def_color_id", combo_get_value (cbm_color_cheme, gl_color_schemes));
+
+#endif
+
    l = add_to_glist_combined_str (l, "fmt_color_function", gtk_entry_get_text (GTK_ENTRY (ent_fmt_color_function)));
 
    l = add_to_glist_combined_str (l, "def_save_dir", gtk_entry_get_text (GTK_ENTRY (ent_def_save_dir)));
@@ -345,10 +389,13 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_str (l, "cm_dvi_to_pdf", gtk_entry_get_text (GTK_ENTRY (ent_cm_dvi_to_pdf)));
 
    l = add_to_glist_combined_str (l, "mplayer", gtk_entry_get_text (GTK_ENTRY (ent_cm_mplayer)));
+   l = add_to_glist_combined_str (l, "cm_pack", gtk_entry_get_text (GTK_ENTRY (ent_cm_pack)));
 
    l = add_to_glist_combined_str (l, "def_doc_browser", gtk_entry_get_text (GTK_ENTRY (ent_cm_manual_browser)));
 
    l = add_to_glist_combined_str (l, "date_time", gtk_entry_get_text (GTK_ENTRY (ent_date_time)));
+   l = add_to_glist_combined_str (l, "date_time_ver", gtk_entry_get_text (GTK_ENTRY (ent_date_time_ver)));
+
    l = add_to_glist_combined_str (l, "now_playing", gtk_entry_get_text (GTK_ENTRY (ent_now_playing)));
 
    l = add_to_glist_combined_str (l, "tag_color_lm_error_fg", gtk_entry_get_text (GTK_ENTRY (ent_tag_color_lm_error_fg)));
@@ -357,6 +404,9 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_str (l, "tag_current_line_fg", gtk_entry_get_text (GTK_ENTRY (ent_tag_current_line_fg)));
    l = add_to_glist_combined_str (l, "tag_current_line_bg", gtk_entry_get_text (GTK_ENTRY (ent_tag_current_line_bg)));
 
+
+   l = add_to_glist_combined_int (l, "fte_min_prefix_len", gtk_spin_button_get_value_as_int (sb_fte_min_prefix_len));
+
    l = add_to_glist_combined_int (l, "margin_visible", gtk_toggle_button_get_active (&cb_margin_visible->toggle_button));
    l = add_to_glist_combined_int (l, "margin_width", gtk_spin_button_get_value_as_int (sb_margin_width));
    l = add_to_glist_combined_int (l, "jpeg_q", gtk_spin_button_get_value_as_int (sb_jpeg_q));
@@ -381,12 +431,17 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
 
    l = add_to_glist_combined_str (l, "text_sel_foreground", gtk_entry_get_text (GTK_ENTRY (ent_text_sel_foreground)));
    l = add_to_glist_combined_str (l, "text_sel_background", gtk_entry_get_text (GTK_ENTRY (ent_text_sel_background)));
+
+#ifndef GTKSOURCEVIEW2_SUPPORTED
+
    l = add_to_glist_combined_str (l, "color_cursor", gtk_entry_get_text (GTK_ENTRY (ent_color_cursor)));
 
+#endif
 
-   l = add_to_glist_combined_str (l, "def_filesave_charset", gtk_entry_get_text (GTK_ENTRY (ent_def_filesave_charset)));
-   l = add_to_glist_combined_str (l, "default_charset", gtk_entry_get_text (GTK_ENTRY (ent_default_charset)));
-   l = add_to_glist_combined_str (l, "rtf_enc", gtk_entry_get_text (GTK_ENTRY (ent_rtf_enc)));
+   l = add_to_glist_combined_str (l, "rtf_enc", gtk_button_get_label (bt_rtf_enc));
+   l = add_to_glist_combined_str (l, "fallback_charset", gtk_button_get_label (bt_fallback_charset));
+   l = add_to_glist_combined_str (l, "default_charset", gtk_button_get_label (bt_default_charset));
+   l = add_to_glist_combined_str (l, "def_filesave_charset", gtk_button_get_label (bt_def_filesave_charset));
 
    l = add_to_glist_combined_str (l, "tag_comment_font", gtk_font_button_get_font_name (fb_tag_comment_font));
    l = add_to_glist_combined_str (l, "tag_identifier_font", gtk_font_button_get_font_name (fb_tag_identifier_font));
@@ -402,8 +457,6 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
 
    l = add_to_glist_combined_str (l, "def_file_ext", gtk_entry_get_text (GTK_ENTRY (ent_def_file_ext)));
 
-
-
    l = add_to_glist_combined_int (l, "exclusive_enter_at_dialogs", gtk_toggle_button_get_active (&cb_exclusive_enter_at_dialogs->toggle_button));
 
    l = add_to_glist_combined_int (l, "common_closing_button_visible", gtk_toggle_button_get_active (&cb_common_closing_button_visible->toggle_button));
@@ -429,13 +482,10 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_int (l, "use_ext_image_viewer", gtk_toggle_button_get_active (&cb_use_ext_image_viewer->toggle_button));
    l = add_to_glist_combined_int (l, "automatic_markup_mode", gtk_toggle_button_get_active (&cb_automatic_markup_mode->toggle_button));
 
-
    l = add_to_glist_combined_int (l, "add_def_file_ext", gtk_toggle_button_get_active (&cb_add_def_file_ext->toggle_button));
    l = add_to_glist_combined_int (l, "homeend", gtk_toggle_button_get_active (&cb_homeend->toggle_button));
    l = add_to_glist_combined_int (l, "show_cursor_pos", gtk_toggle_button_get_active (&cb_show_cursor_pos->toggle_button));
 
-
-   l = add_to_glist_combined_int (l, "do_hl_on_fileopen", gtk_toggle_button_get_active (&cb_do_hl_on_fileopen->toggle_button));
    l = add_to_glist_combined_int (l, "do_backup", gtk_toggle_button_get_active (&cb_do_backup->toggle_button));
 
    l = add_to_glist_combined_int (l, "start_with_blank_file", gtk_toggle_button_get_active (&cb_start_with_blank_file->toggle_button));
@@ -452,6 +502,8 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_int (l, "scan_for_links_on_doc_open", gtk_toggle_button_get_active (&cb_scan_for_links_on_doc_open->toggle_button));
    l = add_to_glist_combined_int (l, "main_wnd_show_full_path", gtk_toggle_button_get_active (&cb_main_wnd_show_full_path->toggle_button));
 
+   l = add_to_glist_combined_int (l, "enc_use_fallback", gtk_toggle_button_get_active (&cb_enc_use_fallback->toggle_button));
+
    l = add_to_glist_combined_int (l, "enc_det_cp1251", gtk_toggle_button_get_active (&cb_enc_det_cp1251->toggle_button));
    l = add_to_glist_combined_int (l, "enc_det_koi8r", gtk_toggle_button_get_active (&cb_enc_det_koi8r->toggle_button));
    l = add_to_glist_combined_int (l, "enc_det_koi8u", gtk_toggle_button_get_active (&cb_enc_det_koi8u->toggle_button));
@@ -481,9 +533,6 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    l = add_to_glist_combined_int (l, "saveopen_h", gtk_spin_button_get_value_as_int (sb_saveopen_h));
    l = add_to_glist_combined_int (l, "tab_size", gtk_spin_button_get_value_as_int (sb_tab_size));
 
-//   l = add_to_glist_combined_int (l, "fam_autocomp_lines_max", gtk_spin_button_get_value_as_int (sb_fam_autocomp_lines_max));
-   //l = add_to_glist_combined_int (l, "fam_min_prefix_len", gtk_spin_button_get_value_as_int (sb_fam_min_prefix_len));
-
    glist_save_to_file (l, confile.tea_rc);
    glist_strings_free (l);
 
@@ -495,7 +544,23 @@ static void cb_on_bt_apply (GtkObject *object, GtkWidget *w)
    update_enc_menu();
 
    if (get_page_text ())
-     markup_change_by_ext (cur_text_doc->file_name_utf8);
+      markup_change_by_ext (cur_text_doc->file_name_utf8);
+}
+
+
+static void cb_on_add_enc (GtkButton *button,
+                           gpointer user_data)
+{
+  gchar *s =  request_item_from_tvlist (gl_enc_available);
+  if (! s)
+     return;
+
+  gl_enc_choosed = g_list_prepend (gl_enc_choosed, s);
+  tv_fill_with_glist (tv_choosed_charsets, gl_enc_choosed);
+
+  glist_save_to_file (gl_enc_choosed, confile.tea_choosed_charsets);
+  get_iconv_sup ();
+  g_free (s);
 }
 
 
@@ -520,9 +585,9 @@ static GtkWidget* wnd_options_encoding (void)
   gtk_widget_show (box);
   gtk_container_add (fr1, box);
 
-  ent_default_charset = tea_combo (box, confile.iconv_encs, _("Default charset for File open"), confile.default_charset);
-  ent_def_filesave_charset = tea_combo (box, confile.gl_save_charsets, _("Default charset for File save as"), confile.def_filesave_charset);
-  ent_rtf_enc = tea_text_entry (box, _("Default charset for RTF"), confile.rtf_enc);
+  bt_default_charset = tea_button_list_items (box, confile.iconv_encs, _("Default charset for File open"), confile.default_charset);
+  bt_def_filesave_charset = tea_button_list_items (box, confile.gl_save_charsets, _("Default charset for File save as"), confile.def_filesave_charset);
+  bt_rtf_enc = tea_button_list_items (box, gl_enc_available, _("Default charset for RTF"), confile.rtf_enc);
 
   fr1 = gtk_frame_new (_("Misc"));
   gtk_widget_show (fr1);
@@ -533,6 +598,8 @@ static GtkWidget* wnd_options_encoding (void)
   gtk_container_add (fr1, box);
 
   cb_det_charset_by_meta = tea_checkbox (box, _("Detect a charset by the [X]HTML meta header"), confile.det_charset_by_meta);
+  cb_enc_use_fallback = tea_checkbox (box, _("On autodetect failed, fallback to this charset:"), confile.enc_use_fallback);
+  bt_fallback_charset = tea_button_list_items (box, gl_enc_available, _("Fallback charset"), confile.fallback_charset);
 
   GtkWidget *fr2 = gtk_frame_new (_("Autodetect"));
   gtk_widget_show (fr2);
@@ -559,18 +626,26 @@ static GtkWidget* wnd_options_encoding (void)
   cb_enc_det_spanish = tea_checkbox (box, _("Spanish"), confile.enc_det_spanish);
   cb_enc_det_turkish = tea_checkbox (box, _("Turkish"), confile.enc_det_turkish);
 
-  //current music: Radiohead - Banana Co.
   gtk_notebook_append_page (enc_tabs, wnd, gtk_label_new (_("Management")));
 
   GtkWidget *hb = gtk_hbox_new (FALSE, UI_PACKFACTOR);
 
   gtk_widget_show (hb);
 
-  tv_available_charsets = tv_create_framed (hb, _("Available"), GTK_SELECTION_SINGLE);
-  tv_fill_with_glist (tv_available_charsets, gl_enc_available);
+  GtkWidget *vbuttons = gtk_vbox_new (FALSE, UI_PACKFACTOR);
+  gtk_box_pack_start (hb, vbuttons, FALSE, FALSE, UI_PACKFACTOR);
+  gtk_widget_show (vbuttons);
 
-  GtkVBox *buttons = daisho_add_del (cb_on_choose_enc, cb_on_del_enc);
-  gtk_box_pack_start (hb, buttons, FALSE, FALSE, UI_PACKFACTOR);
+  GtkWidget *b1 = gtk_button_new_from_stock (GTK_STOCK_ADD);
+  GtkWidget *b2 = gtk_button_new_from_stock (GTK_STOCK_DELETE);
+  gtk_widget_show (b1);
+  gtk_widget_show (b2);
+
+  gtk_box_pack_start (vbuttons, b1, FALSE, FALSE, UI_PACKFACTOR);
+  gtk_box_pack_start (vbuttons, b2, FALSE, FALSE, UI_PACKFACTOR);
+
+  g_signal_connect (b1, "clicked", G_CALLBACK (cb_on_add_enc), NULL);
+  g_signal_connect (b2, "clicked", G_CALLBACK (cb_on_del_enc), NULL);
 
   tv_choosed_charsets = tv_create_framed (hb, _("Selected"), GTK_SELECTION_SINGLE);
   tv_fill_with_glist (tv_choosed_charsets, gl_enc_choosed);
@@ -597,6 +672,7 @@ static GtkWidget* wnd_options_commands (void)
   ent_ext_pic_editor = tea_text_entry (b, _("External image editor"), confile.ext_pic_editor);
   ent_ext_pic_viewer = tea_text_entry (b, _("External image viewer"), confile.ext_pic_viewer);
   ent_cm_mplayer = tea_text_entry (b, _("Run Mplayer with subtitles"), confile.cm_mplayer);
+  ent_cm_pack = tea_text_entry (b, _("A command for Save packed"), confile.cm_pack);
 
   ent_cm_manual_browser = tea_text_entry (b, _("Browser for the manual"), confile.cmd_def_doc_browser);
   cb_use_def_doc_browser = tea_checkbox (b, _("Use this browser"), confile.use_def_doc_browser);
@@ -627,6 +703,8 @@ static GtkWidget* wnd_options_functions (void)
   gtk_widget_show (page);
   ent_now_playing = tea_text_entry (page, _("Now Playing string format"), confile.now_playing);
   ent_date_time = tea_text_entry (page, _("Date and time format"), confile.date_time);
+  ent_date_time_ver = tea_text_entry (page, _("Date format for Save version"), confile.date_time_ver);
+
   ent_fmt_color_function = tea_text_entry (page, _("The format of the Color function"), confile.fmt_color_function);
   sb_jpeg_q = tea_spinbutton (page, _("JPEG compression (1..100)"), confile.jpeg_q);
   sb_screenshot_delay = tea_spinbutton (page, _("Screenshot delay (in seconds)"), confile.screenshot_delay);
@@ -645,7 +723,6 @@ static GtkWidget* wnd_options_interface (void)
   sb_thumb_width = tea_spinbutton (page, _("Image thumbnail width"), confile.thumb_width);
   sb_thumb_height = tea_spinbutton (page, _("Image thumbnail height"), confile.thumb_height);
 
-
   cb_exclusive_enter_at_dialogs = tea_checkbox (page, _("Exclusive \"Enter\" mode at save/open dialogs"), confile.exclusive_enter_at_dialogs);
   cb_main_wnd_show_full_path = tea_checkbox (page, _("Show the full path in the window caption"), confile.main_wnd_show_full_path);
   cb_do_show_main_toolbar = tea_checkbox (page, _("Show the main toolbar"), confile.do_show_main_toolbar);
@@ -659,8 +736,7 @@ static GtkWidget* wnd_options_interface (void)
   sb_max_recent_items = tea_spinbutton (page, _("Max. recent files"), confile.max_recent_items);
   sb_logmemo_lines_max = tea_spinbutton (page, _("Logmemo lines limit"), confile.logmemo_lines_max);
 
-//   = tea_spinbutton (page, _("Famous text entry autocompletion list max items"), confile.fam_autocomp_lines_max);
- // sb_fam_min_prefix_len = tea_spinbutton (page, _("Famous text entry autocompletion minimun prefix length"), confile.fam_min_prefix_len);
+  sb_fte_min_prefix_len = tea_spinbutton (page, _("Famous text entry autocompletion min. prefix, in characters"), confile.fte_min_prefix_len);
 
   return page;
 }
@@ -681,7 +757,7 @@ static GtkWidget* wnd_options_switches (void)
 
   cb_do_det_scripts_by_content = tea_checkbox (page, _("Determine a scripts highlighting by the content"), confile.do_det_scripts_by_content);
 
-#ifndef CHAI_MODE
+#ifndef LEGACY_MODE
 
   gtk_widget_hide (cb_do_det_scripts_by_content);
 
@@ -689,7 +765,6 @@ static GtkWidget* wnd_options_switches (void)
 
   cb_show_hidden_files = tea_checkbox (page, _("Show hidden files in Kwas"), confile.show_hidden_files);
   cb_use_ext_image_viewer = tea_checkbox (page, _("Use external image viewer"), confile.use_ext_image_viewer);
-  cb_do_hl_on_fileopen = tea_checkbox (page, _("Highlight on file open"), confile.do_hl_on_fileopen);
   cb_do_backup = tea_checkbox (page, _("Do backup"), confile.do_backup);
   cb_show_line_nums = tea_checkbox (page, _("Show line numbers"), confile.show_line_nums);
   cb_word_wrap = tea_checkbox (page, _("Word wrap"), confile.word_wrap);
@@ -722,7 +797,7 @@ static void cb_backup_config (GtkButton *button,
 
 
 static void cb_change_all_fonts (GtkButton *button,
-                                gpointer user_data)
+                                 gpointer user_data)
 {
   GtkFontSelectionDialog *w = gtk_font_selection_dialog_new (_("Please select the font"));
   gchar *font_name;
@@ -747,6 +822,7 @@ static void cb_change_all_fonts (GtkButton *button,
   gtk_widget_destroy (w);
 }
 
+
 static void cb_restore_config (GtkButton *button,
                                gpointer user_data)
 {
@@ -1053,6 +1129,14 @@ static void cb_session_remove (GtkButton *button,
 }
 
 
+static void cb_del_fteautocomp (GtkButton *button,
+                               gpointer user_data)
+
+{
+  unlink (confile.fam_autocomp_file);
+}
+
+
 static void cb_session_rename (GtkButton *button,
                               gpointer user_data)
 {
@@ -1098,8 +1182,8 @@ static GtkWidget* wnd_options_maintenance (void)
   b = tea_button_at_box (page, _("Reset config to default" ), cb_config_reset, NULL);
   b = tea_button_at_box (page, _("Put the launcher to the desktop" ), cb_put_launcher, NULL);
   b = tea_button_at_box (page, _("Remove the launcher from the desktop" ), cb_del_launcher, NULL);
+  b = tea_button_at_box (page, _("Clear the Famous text entry history" ), cb_del_fteautocomp, NULL);
 
-/////////
   page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
   gtk_notebook_append_page (notebook, page, gtk_label_new (_("Templates")));
@@ -1131,7 +1215,7 @@ static GtkWidget* wnd_options_maintenance (void)
 
   b = tea_button_at_box (vbox, _("Remove"), cb_snippet_remove, tv_snippets);
   b = tea_button_at_box (vbox, _("Rename"), cb_snippet_rename, tv_snippets);
-///////
+
   page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
   gtk_notebook_append_page (notebook, page, gtk_label_new (_("Sessions")));
@@ -1147,7 +1231,7 @@ static GtkWidget* wnd_options_maintenance (void)
 
   b = tea_button_at_box (vbox, _("Remove"), cb_session_remove, tv_sessions);
   b = tea_button_at_box (vbox, _("Rename"), cb_session_rename, tv_sessions);
-//
+
   page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
   gtk_notebook_append_page (notebook, page, gtk_label_new (_("Scripts")));
@@ -1164,7 +1248,7 @@ static GtkWidget* wnd_options_maintenance (void)
   b = tea_button_at_box (vbox, _("Add"), cb_script_add, tv_scripts);
   b = tea_button_at_box (vbox, _("Remove"), cb_script_remove, tv_scripts);
   b = tea_button_at_box (vbox, _("Rename"), cb_script_rename, tv_scripts);
-///////
+
   page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
   gtk_notebook_append_page (notebook, page, gtk_label_new (_("Tables")));
@@ -1199,8 +1283,13 @@ static GtkWidget* wnd_options_colors (void)
   ent_text_background = tea_color_selector (page, _("Text background"), confile.text_background);
   ent_text_sel_foreground = tea_color_selector (page, _("Selected foreground"), confile.text_sel_foreground);
   ent_text_sel_background = tea_color_selector (page, _("Selected background"), confile.text_sel_background);
+
+#ifndef GTKSOURCEVIEW2_SUPPORTED
+
   ent_color_cursor = tea_color_selector (page, _("Cursor color"), confile.color_cursor);
 
+#endif
+
   ent_tag_color_paint_fg = tea_color_selector (page, _("Marking function foreground"), confile.tag_color_paint_fg);
   ent_tag_color_paint_bg = tea_color_selector (page, _("Marking function background"), confile.tag_color_paint_bg);
 
@@ -1221,7 +1310,7 @@ static GtkWidget* wnd_options_colors (void)
   ent_tag_preprocessor = tea_color_selector (page, _("Preprocessor"), confile.tag_preprocessor);
   ent_tag_type = tea_color_selector (page, _("Types"), confile.tag_type);
 
-  #ifdef CHAI_MODE
+  #ifndef LEGACY_MODE
 
   gtk_widget_hide (page);
 
@@ -1243,7 +1332,7 @@ static GtkWidget* wnd_options_fonts (void)
   GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
 
-#ifndef CHAI_MODE
+#ifdef LEGACY_MODE
 
   fb_editor_font = tea_font_button (page, _("Editor font"), confile.editor_font);
 
@@ -1268,7 +1357,7 @@ static GtkWidget* wnd_options_editor (void)
   GtkWidget *page = gtk_vbox_new (FALSE, UI_PACKFACTOR);
   gtk_widget_show (page);
 
-#ifdef CHAI_MODE
+#ifndef LEGACY_MODE
 
   fb_editor_font = tea_font_button (page, _("Font"), confile.editor_font);
 
@@ -1293,10 +1382,11 @@ static GtkWidget* wnd_options_editor (void)
   cb_margin_visible = tea_checkbox (page, _("Show the margin"), confile.margin_visible);
   sb_margin_width = tea_spinbutton (page, _("Position of the margin (GtkSourceView-only)"), confile.margin_width);
 
-#ifndef CHAI_MODE
+#ifdef LEGACY_MODE
 
   gtk_widget_hide (cb_margin_visible);
   gtk_widget_hide (sb_max_undo_levels);
+  gtk_widget_hide (sb_margin_width);
 
 #endif
 
@@ -1332,6 +1422,8 @@ static void cb_menuitem_ch_cursor (GtkTreeView *tree_view, gpointer user_data)
     gtk_entry_set_text (ent_shortcut, value);
   else
       gtk_entry_set_text (ent_shortcut, "");
+
+ g_free (sel);
 }
 
 
@@ -1378,6 +1470,7 @@ static void cb_shortcut_remove (GtkButton *button,
   if (! x)
      return;
   shortcut_remove_by_menuitem_name (x, TRUE);
+  g_free (x);
 }
 
 
@@ -1418,8 +1511,10 @@ static void cb_shortcut_assign (GtkButton *button,
 
   GtkWidget *w = find_menuitem (GTK_CONTAINER (menubar1), keyname);
   if (! w)
-     return;
-
+     {
+      g_free (keyname);
+      return;
+     }
   gchar *key;
   gchar *t = g_strrstr (shortcut, " ");
   if (! t)
@@ -1434,6 +1529,8 @@ static void cb_shortcut_assign (GtkButton *button,
   g_hash_table_insert (ht_tea_hotkeys, keyname, shortcut);
 
   save_ht_to_file (ht_tea_hotkeys, confile.tea_hotkeys);
+  g_free (keyname);
+
 }
 
 
@@ -1457,7 +1554,7 @@ static GtkWidget* wnd_options_keyboard (void)
   GtkWidget *ent_qsearch = tea_text_entry (vbleft, _("Quick search"), NULL);
 #endif
 
-  tv_menuitems = tv_create_non_framed (vbleft, "hello", GTK_SELECTION_SINGLE);
+  tv_menuitems = tv_create_non_framed (vbleft, GTK_SELECTION_SINGLE);
 
 #if ((GTK_MAJOR_VERSION >= 2) && (GTK_MINOR_VERSION >= 10))
   gtk_tree_view_set_search_entry (tv_menuitems, ent_qsearch);
@@ -1508,7 +1605,7 @@ GtkWidget* wnd_options_create (void)
 
   page_fonts = wnd_options_fonts ();
 
-#ifndef CHAI_MODE
+#ifdef LEGACY_MODE
   gtk_notebook_append_page (notebook, page_fonts, gtk_label_new (_("Fonts")));
 #endif
 
@@ -1519,15 +1616,17 @@ GtkWidget* wnd_options_create (void)
  gtk_notebook_append_page (notebook, wnd_options_hl_chai (), gtk_label_new (_("Highlighting")));
 #endif
 
-  gtk_notebook_append_page (notebook, wnd_options_colors (), gtk_label_new (_("Colors")));
+#ifdef GTKSOURCEVIEW2_SUPPORTED
+ gtk_notebook_append_page (notebook, wnd_options_hl_schemes (), gtk_label_new (_("Highlighting")));
+#endif
 
+  gtk_notebook_append_page (notebook, wnd_options_colors (), gtk_label_new (_("Colors")));
   gtk_notebook_append_page (notebook, wnd_options_commands (), gtk_label_new (_("Commands")));
   gtk_notebook_append_page (notebook, wnd_options_paths (), gtk_label_new (_("Paths")));
   gtk_notebook_append_page (notebook, wnd_options_confirmations (), gtk_label_new (_("Confirmations")));
   gtk_notebook_append_page (notebook, wnd_options_maintenance (), gtk_label_new (_("Maintenance")));
   gtk_notebook_append_page (notebook, wnd_options_keyboard (), gtk_label_new (_("Keyboard")));
 
-
   gtk_notebook_set_current_page (notebook, confile.last_prefs_tab);
 
   g_signal_connect ((gpointer) notebook, "switch_page",
